pub struct Config {
pub bootnodes: Vec<TrustedPeer>,
pub stages: StageConfig,
pub prune: PruneConfig,
pub peers: PeersConfig,
pub sessions: SessionsConfig,
pub static_files: StaticFilesConfig,
}Expand description
Configuration for the reth node.
Fields
bootnodes: Vec<TrustedPeer>Nodes to bootstrap P2P discovery with, as enode:// URLs or enr: records.
Takes precedence over the chain spec bootnodes, and is overridden by --bootnodes.
stages: StageConfigConfiguration for each stage in the pipeline.
prune: PruneConfigConfiguration for pruning.
peers: PeersConfigConfiguration for the discovery service.
sessions: SessionsConfigConfiguration for peer sessions.
static_files: StaticFilesConfigConfiguration for static files.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn set_prune_config(&mut self, prune_config: PruneConfig)
pub fn set_prune_config(&mut self, prune_config: PruneConfig)
Sets the pruning configuration.
Sourceimpl Config
impl Config
Sourcepub fn from_path(path: impl AsRef<Path>) -> Result<Self>
Available on crate feature serde only.
pub fn from_path(path: impl AsRef<Path>) -> Result<Self>
serde only.Load a Config from a specified path.
A new configuration file is created with default values if none exists.
Sourcepub fn peers_config_with_basic_nodes_from_file(
&self,
peers_file: Option<&Path>,
) -> PeersConfig
Available on crate feature serde only.
pub fn peers_config_with_basic_nodes_from_file( &self, peers_file: Option<&Path>, ) -> PeersConfig
serde only.Returns the PeersConfig for the node.
If a peers file is provided, the basic nodes from the file are added to the configuration.